@@ -1,11 +1,11 @@
-# $Id: Tk.pm 1903 2006-03-20 04:44:08Z rcaputo $
+# $Id: Tk.pm 2447 2009-02-17 05:04:43Z rcaputo $
 
 # Tk-Perl event loop bridge for POE::Kernel.
 
 package POE::Loop::Tk;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 1903 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2447 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # Include common things.
 use POE::Loop::PerlSignals;
@@ -14,6 +14,22 @@ use POE::Loop::TkCommon;
 use Tk 800.021;
 use 5.00503;
 
+=for poe_tests
+
+sub skip_tests {
+  return "Tk needs a DISPLAY (set one today, okay?)" unless (
+    (defined $ENV{DISPLAY} and length $ENV{DISPLAY}) or $^O eq "MSWin32"
+  );
+  my $test_name = shift;
+  if ($test_name eq "k_signals_rerun" and $^O eq "MSWin32") {
+    return "This test crashes Perl when run with Tk on $^O";
+  }
+  return "Tk tests require the Tk module" if do { eval "use Tk"; $@ };
+  return;
+}
+
+=cut
+
 # Everything plugs into POE::Kernel.
 package POE::Kernel;
 
@@ -43,7 +59,8 @@ sub loop_initialize {
 }
 
 sub loop_finalize {
-  # does nothing
+  my $self = shift;
+  $self->loop_ignore_all_signals();
 }
 
 #------------------------------------------------------------------------------
@@ -184,7 +201,7 @@ __END__
 
 =head1 NAME
 
-POE::Loop::Tk - a bridge that supports Tk's event loop from POE
+POE::Loop::Tk - a bridge that allows POE to be driven by Tk
 
 =head1 SYNOPSIS
 
@@ -192,13 +209,20 @@ See L<POE::Loop>.
 
 =head1 DESCRIPTION
 
-This class is an implementation of the abstract POE::Loop interface.
-It follows POE::Loop's public interface exactly.  Therefore, please
-see L<POE::Loop> for its documentation.
+POE::Loop::Tk implements the interface documented in L<POE::Loop>.
+Therefore it has no documentation of its own.  Please see L<POE::Loop>
+for more details.
+
+POE::Loop::Tk is one of two versions of the Tk event loop bridge.  The
+other, L<POE::Loop::TkActiveState> accommodates behavior differences
+in ActiveState's build of Tk.  Both versions share common code in
+L<POE::Loop::TkCommon>.  POE::Loop::Tk dynamically selects the
+appropriate bridge code based on the runtime enviroment.
 
 =head1 SEE ALSO
 
-L<POE>, L<POE::Loop>, L<Tk>
+L<POE>, L<POE::Loop>, L<Tk>, L<POE::Loop::TkCommon>,
+L<POE::Loop::PerlSignals>.
 
 =head1 AUTHORS & LICENSING
 
@@ -206,3 +230,6 @@ Please see L<POE> for more information about authors, contributors,
 and POE's licensing.
 
 =cut
+
+# rocco // vim: ts=2 sw=2 expandtab
+# TODO - Edit.
