@@ -1,11 +1,11 @@
-# $Id: Events.pm 2087 2006-09-01 10:24:43Z bsmith $
+# $Id: Events.pm 2447 2009-02-17 05:04:43Z rcaputo $
 
 # Data and accessors to manage POE's events.
 
 package POE::Resource::Events;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2087 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2447 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -123,7 +123,7 @@ sub _data_ev_clear_session {
   croak if delete $post_count{$session};
 }
 
-# -><- Alarm maintenance functions may move out to a separate
+# TODO Alarm maintenance functions may move out to a separate
 # POE::Resource module in the future.  Why?  Because alarms may
 # eventually be managed by something other than the event queue.
 # Especially if we incorporate a proper Session scheduler.  Be sure to
@@ -150,7 +150,7 @@ sub _data_ev_clear_alarm_by_name {
 
 ### Remove a specific alarm by its ID.  This is in the events section
 ### because alarms are currently implemented as events with future due
-### times.  -><- It's possible to remove non-alarms; is that wrong?
+### times.  TODO It's possible to remove non-alarms; is that wrong?
 
 sub _data_ev_clear_alarm_by_id {
   my ($self, $session, $alarm_id) = @_;
@@ -162,6 +162,13 @@ sub _data_ev_clear_alarm_by_id {
   my ($time, $id, $event) = $kr_queue->remove_item($alarm_id, $my_alarm);
   return unless defined $time;
 
+  if (TRACE_EVENTS) {
+    _warn(
+      "<ev> removed event $id ``", $event->[EV_NAME], "'' to ",
+      $self->_data_alias_loggable($session), " at $time"
+    );
+  }
+
   $self->_data_ev_refcount_dec( @$event[EV_SOURCE, EV_SESSION] );
   return ($time, $event);
 }
@@ -225,9 +232,10 @@ sub _data_ev_dispatch_due {
 
   if (TRACE_EVENTS) {
     foreach ($kr_queue->peek_items(sub { 1 })) {
+      my @event = map { defined() ? $_ : "(undef)" } @{$_->[ITEM_PAYLOAD]};
       _warn(
         "<ev> time($_->[ITEM_PRIORITY]) id($_->[ITEM_ID]) ",
-        "event(@{$_->[ITEM_PAYLOAD]})\n"
+        "event(@event)\n"
       );
     }
   }
@@ -272,7 +280,14 @@ sub _data_ev_dispatch_due {
     }
   }
 
-  $self->loop_reset_time_watcher($next_time);
+  # Tell the event loop to wait for the next event, if there is one.
+  # Otherwise we're going to wait indefinitely for some other event.
+  if (defined $next_time) {
+    $self->loop_reset_time_watcher($next_time);
+  }
+  else {
+    $self->loop_pause_time_watcher();
+  }
 }
 
 1;
@@ -281,29 +296,38 @@ __END__
 
 =head1 NAME
 
-POE::Resource::Events - manage events for POE::Kernel
+POE::Resource::Events - internal event manager for POE::Kernel
 
 =head1 SYNOPSIS
 
-Used internally by POE::Kernel.  Better documentation will be
-forthcoming.
+There is no public API.
 
 =head1 DESCRIPTION
 
-This module hides the complexity of managing POE's events from even
-POE itself.  It is used internally by POE::Kernel and has no public
-interface.
+POE::Resource::Events is a mix-in class for POE::Kernel.  It hides the
+complexity of managing POE's events from even POE itself.  It is used
+internally by POE::Kernel, so it has no public interface.
 
 =head1 SEE ALSO
 
-See L<POE::Kernel> for documentation on events.
+See L<POE::Kernel/Asynchronous Messages (FIFO Events)> for one public
+events API.
+
+See L<POE::Kernel/Resources> for for public information about POE
+resources.
+
+See L<POE::Resource> for general discussion about resources and the
+classes that manage them.
 
 =head1 BUGS
 
-Probably.
+None known.
 
 =head1 AUTHORS & COPYRIGHTS
 
 Please see L<POE> for more information about authors and contributors.
 
 =cut
+
+# rocco // vim: ts=2 sw=2 expandtab
+# TODO - Edit.
