@@ -1,5 +1,6 @@
 #!/usr/bin/perl
-# $Id: Makefile-5004.pm 1995 2006-06-18 20:33:55Z rcaputo $
+# $Id: Makefile-5004.pm 2391 2008-07-05 22:50:47Z rcaputo $
+# rocco // vim: ts=2 sw=2 expandtab
 
 use strict;
 
@@ -7,6 +8,7 @@ use ExtUtils::MakeMaker;
 
 use lib qw(./mylib);
 use PoeBuildInfo qw(
+  TEST_FILES
   CLEAN_FILES
   CORE_REQUIREMENTS
 );
@@ -18,9 +20,9 @@ use PoeBuildInfo qw(
 open(TOUCH, ">>CHANGES") and close TOUCH;
 open(TOUCH, ">>META.yml") and close TOUCH;
 
-### Generate dynamic test files.
+### Touch gen-tests.perl so it always triggers.
 
-system($^X, "mylib/gen-tests.perl") and die "couldn't generate tests: $!";
+utime(time(), time(), "mylib/gen-tests.perl");
 
 ### Generate Makefile.PL.
 
@@ -54,9 +56,16 @@ WriteMakefile(
     FILES => CLEAN_FILES,
   },
 
-  PL_FILES  => { },
+  test => {
+    TESTS => TEST_FILES,
+  },
+
+  # Not executed on "make test".
+  PL_FILES  => {
+    'mylib/gen-tests.perl' => [ 'lib/POE.pm' ],
+  },
+
   PREREQ_PM => { CORE_REQUIREMENTS },
-  PM_FILTER => 'mylib/preprocessor.perl',
 );
 
 1;
